@@ -9,11 +9,14 @@
 #define YYRECOVERING (ssl_expr_yyerrflag!=0)
 static int ssl_expr_yygrowstack();
 #define YYPREFIX "ssl_expr_yy"
+#line 72 "ssl_expr_parse.y"
 #include "mod_ssl.h"
+#line 75 "ssl_expr_parse.y"
 typedef union {
     char     *cpVal;
     ssl_expr *exVal;
 } YYSTYPE;
+#line 29 "y.tab.c"
 #define T_TRUE 257
 #define T_FALSE 258
 #define T_DIGIT 259
@@ -210,6 +213,7 @@ short *ssl_expr_yyss;
 short *ssl_expr_yysslim;
 YYSTYPE *ssl_expr_yyvs;
 int ssl_expr_yystacksize;
+#line 180 "ssl_expr_parse.y"
 
 int ssl_expr_yyerror(char *s)
 {
@@ -217,6 +221,7 @@ int ssl_expr_yyerror(char *s)
     return 2;
 }
 
+#line 232 "y.tab.c"
 /* allocate initial stack or double stack size, up to YYMAXDEPTH */
 static int ssl_expr_yygrowstack()
 {
@@ -386,75 +391,99 @@ ssl_expr_yyreduce:
     switch (ssl_expr_yyn)
     {
 case 1:
+#line 118 "ssl_expr_parse.y"
 { ssl_expr_info.expr = ssl_expr_yyvsp[0].exVal; }
 break;
 case 2:
+#line 121 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_True,  NULL, NULL); }
 break;
 case 3:
+#line 122 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_False, NULL, NULL); }
 break;
 case 4:
+#line 123 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_Not,   ssl_expr_yyvsp[0].exVal,   NULL); }
 break;
 case 5:
+#line 124 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_Or,    ssl_expr_yyvsp[-2].exVal,   ssl_expr_yyvsp[0].exVal);   }
 break;
 case 6:
+#line 125 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_And,   ssl_expr_yyvsp[-2].exVal,   ssl_expr_yyvsp[0].exVal);   }
 break;
 case 7:
+#line 126 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_Comp,  ssl_expr_yyvsp[0].exVal,   NULL); }
 break;
 case 8:
+#line 127 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_yyvsp[-1].exVal; }
 break;
 case 9:
+#line 130 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_EQ,  ssl_expr_yyvsp[-2].exVal, ssl_expr_yyvsp[0].exVal); }
 break;
 case 10:
+#line 131 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_NE,  ssl_expr_yyvsp[-2].exVal, ssl_expr_yyvsp[0].exVal); }
 break;
 case 11:
+#line 132 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_LT,  ssl_expr_yyvsp[-2].exVal, ssl_expr_yyvsp[0].exVal); }
 break;
 case 12:
+#line 133 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_LE,  ssl_expr_yyvsp[-2].exVal, ssl_expr_yyvsp[0].exVal); }
 break;
 case 13:
+#line 134 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_GT,  ssl_expr_yyvsp[-2].exVal, ssl_expr_yyvsp[0].exVal); }
 break;
 case 14:
+#line 135 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_GE,  ssl_expr_yyvsp[-2].exVal, ssl_expr_yyvsp[0].exVal); }
 break;
 case 15:
+#line 136 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_IN,  ssl_expr_yyvsp[-4].exVal, ssl_expr_yyvsp[-1].exVal); }
 break;
 case 16:
+#line 137 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_REG, ssl_expr_yyvsp[-2].exVal, ssl_expr_yyvsp[0].exVal); }
 break;
 case 17:
+#line 138 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_NRE, ssl_expr_yyvsp[-2].exVal, ssl_expr_yyvsp[0].exVal); }
 break;
 case 18:
+#line 141 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_ListElement, ssl_expr_yyvsp[0].exVal, NULL); }
 break;
 case 19:
+#line 142 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_ListElement, ssl_expr_yyvsp[0].exVal, ssl_expr_yyvsp[-2].exVal);   }
 break;
 case 20:
+#line 145 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_Digit,  ssl_expr_yyvsp[0].cpVal, NULL); }
 break;
 case 21:
+#line 146 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_String, ssl_expr_yyvsp[0].cpVal, NULL); }
 break;
 case 22:
+#line 147 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_make(op_Var,    ssl_expr_yyvsp[-1].cpVal, NULL); }
 break;
 case 23:
+#line 148 "ssl_expr_parse.y"
 { ssl_expr_yyval.exVal = ssl_expr_yyvsp[0].exVal; }
 break;
 case 24:
+#line 151 "ssl_expr_parse.y"
 { 
                 regex_t *regex;
                 if ((regex = ap_pregcomp(ssl_expr_info.pool, ssl_expr_yyvsp[0].cpVal, 
@@ -467,6 +496,7 @@ case 24:
             }
 break;
 case 25:
+#line 161 "ssl_expr_parse.y"
 {
                 regex_t *regex;
                 if ((regex = ap_pregcomp(ssl_expr_info.pool, ssl_expr_yyvsp[0].cpVal, 
@@ -479,11 +509,13 @@ case 25:
             }
 break;
 case 26:
+#line 173 "ssl_expr_parse.y"
 { 
                ssl_expr *args = ssl_expr_make(op_ListElement, ssl_expr_yyvsp[-1].cpVal, NULL);
                ssl_expr_yyval.exVal = ssl_expr_make(op_Func, "file", args);
             }
 break;
+#line 526 "y.tab.c"
     }
     ssl_expr_yyssp -= ssl_expr_yym;
     ssl_expr_yystate = *ssl_expr_yyssp;
