@@ -29,6 +29,9 @@
   )
 
 */
+#include "err.h"
+#include "asn1_mac.h"
+#include "ssl.h"
 
 /*
  * "id"     a character string that is an identity within a zone
